\name{dnormp}
\alias{dnormp}
\title{Density function of a Normal of Order p Distribution}
\description{Density function for the normal of order \eqn{p}{p} distribution with location parameter \code{mu},
scale parameter \code{sigmap} and structure parameter \code{p}.}
\usage{
dnormp(x, mu=0, sigmap=1, p=2, log=FALSE)
}
\arguments{
    \item{x}{Vector of quantiles.}
    \item{mu}{Vector of location parameters.}
    \item{sigmap}{Vector of scale parameters.}
    \item{p}{Structure parameter.}
    \item{log}{Logical; if TRUE, the density is given as log(density).}
}
\details{If \code{mu}, \code{sigmap} or \code{p} are not specified they assume the default values 0, 1 and 2,
respectively.
The normal of order \eqn{p}{p} distribution has density function

\deqn{f(x) = \frac{1}{2 p^{(1/p)} \Gamma(1+1/p) \sigma_p} e^{-\frac{|x - \mu|^p}{p \sigma_p^p}}}{%
f(x) = 1/(2 p^(1/p) Gamma(1+1/p) sigmap) exp{-|x - mu|^p/(p sigmap^p)}}

where \eqn{\mu}{mu} is the location parameter, \eqn{\sigma_p}{sigmap} the scale parameter and \eqn{p}{p} the
structure parameter.
When \eqn{p=2}{p=2} the Normal of Order \eqn{p}{p} Distribution becomes the Normal (Gaussian) Distribution, when
\eqn{p=1}{p=1} the Normal of Order \eqn{p}{p} Distribution becomes the Laplace Distribution, when
\eqn{p\rightarrow\infty}{p->infinity} the Normal of Order \eqn{p}{p} Distribution becomes the Uniform Distribution.
}
\value{\code{dnormp} gives the density function of a normal of order \eqn{p}{p} distribution.}
\seealso{\code{\link{Normal}} for the Normal distribution, \code{\link{Uniform}} for the Uniform distribution,
and \code{\link{Special}} for the Gamma function. }
\examples{
## Compute the density for a vector x with mu=0, sigmap=1 and p=1.5
## At the end we have the graph of the Normal of order p density function with p=1.5
x <- c(-1, 1)
f <- dnormp(x, p=1.5)
print(f)
plot(function(x) dnormp(x, p=1.5) , -4, 4,
          main = "Normal of order p Density function (p=1.5)", ylab="f(x)")
}
\keyword{distribution}
\author{Angelo M. Mineo}
\eof
\name{estimatep}
\alias{estimatep}
\title{Estimation of p}
\description{The \code{estimatep} function estimates the structure parameter \eqn{p} from a vector of observations.
}
\usage{
estimatep(x, mu, p=2, method=c("inverse","direct"))
}
\arguments{
    \item{x}{Vector of observations.}
    \item{mu}{An estimate of the location parameter.}
    \item{p}{Starting value of the structure parameter.}
    \item{method}{Method used to estimate \eqn{p}{p} from a sample.}
}
\details{The used algorithm is based on a method proposed by A.M. Mineo, which uses a particular
 index of kurtosis, called \eqn{VI}{VI}

\deqn{VI=\frac{\sqrt{\Gamma(1/p)\Gamma(3/p)}}{\Gamma(2/p)}.}{%
VI=[(G(1/p) G(3/p))^{1/2}]/G(2/p).}

With \code{method} the user can choice between an inverse interpolation (faster) or a
direct solution of the equation

\deqn{\hat{VI}=\frac{\sqrt{\Gamma(1/p)\Gamma(3/p)}}{\Gamma(2/p)}.}{%
(Estimate o VI)=[(G(1/p) G(3/p))^{1/2}]/G(2/p).}
}
\value{An estimate of \eqn{p}{p} from a sample of observations.}
\references{Mineo, A.M. (1994) \emph{Un nuovo metodo di stima di p per una corretta valutazione dei
parametri di intensit\`a e di scala di una curva normale di ordine p}, 
Atti della XXXVII Riunione Scientifica della Societ Italiana di Statistica, San Remo, Vol. 2, pp. 147-154.
}
\examples{
x<-rnormp(300,mu=1,sigmap=2,p=4)
p<-estimatep(x,mu=1,p=2)
p
}
\keyword{univar}
\author{Angelo M. Mineo}
\eof
\name{graphnp}
\alias{graphnp}
\title{Plot of Normal of order p distributions}
\description{The function \code{graphnp} returns on the same device, marked with different colours,
from one to five normal of order \eqn{p}{p} curves.}
\usage{
graphnp(p=c(1,2,3,4,5), mu=0, sigmap=1, title="Normal of order p curves")
}
\arguments{
\item{p}{A vector of \eqn{p}{p} values. His length must be maximum five.}
\item{mu}{Value of the location parameter.}
\item{sigmap}{Value of the scale parameter.}
\item{title}{The title of the plot.}
}
\details{If one or more values of \code{p} are greater than or equal to 50, \code{graphnp}
will plot the density of an uniform distribution.
}
\value{A graphic device with till five different curves. The curves have different colours and
the device is completed by a legend.
}
\examples{
## Plot four different curves with p=1,2,3,4
## and 50 (it will plot a uniform distribution)
graphnp(c(1:4,50))
}
\keyword{aplot}
\author{Angelo M. Mineo}
\eof
\name{kurtosis}
\alias{kurtosis}
\title{Indexes of kurtosis}
\description{This function computes the theoretical and empirical values of three indexes of kurtosis.
}
\usage{
kurtosis(x, p=3, value="parameter")
}
\arguments{
    \item{x}{A sample of observations.}
    \item{p}{the structure parameter.}
    \item{value}{If is set to \code{estimate}, evaluate the indexes using an estimate of \eqn{p}{p}.
    Otherwise, if is set to \code{parameter} it uses the value specified in \code{p}.}
}
\value{
It returns the vector of the three indexes of kurtosis \eqn{VI}{VI}, \eqn{\beta_2}{Beta2}
and \eqn{\beta_p}{Betap}.
Giving a vector as argument, it returns the estimates of the three indexes, computed on the sample.
On the other hand, giving the value of the structure parameter \eqn{p}{p}, it returns the theoretical indexes.
}
\references{Mineo, A.M. (1996) \emph{La migliore combinazione delle osservazioni: curve normali di ordine p e
stimatori di norma Lp}. PhD thesis.
}
\examples{
kurtosis(p=2)
x<-rnormp(50,mu=0,sigmap=2,p=1.5)
kurtosis(x,p=2)
}
\keyword{univar}
\author{Angelo M. Mineo}
\eof
\name{lmp}
\alias{lmp}
\alias{lmp.default}
\title{Fitted linear model with normal of order p errors}
\description{The function \code{lmp} is used to fit linear model. It can be used when the errors are
distributed as a Normal of order \eqn{p}{p} distribution.
}
\usage{
lmp(formula, data=list(), p=NULL)
}
\arguments{
\item{formula}{A symbolic description of the model to be fitted.}
\item{data}{An optional data frame containing the variables in the model.
By default the variables are taken from environment.}
\item{p}{The structure parameter. If specified, this function estimates the parameter by using the
\eqn{L_p-norm}{Lp-norm} method.}
}
\details{To evaluate the coefficients of the linear model, \code{lmp} uses the maximum likelyhood estimators.
This function can give some problems if the number of regressors is too high.}
\value{
The function \code{lmp} returns an object of \code{\link{class}} \code{"lmp"} and \code{"lm"}. The function
\code{summary} print a summary of the results.
The generic accessor functions \code{coefficients, effects, fitted.values} and
\code{residuals} extract various useful features of the value returned by \code{lmp}.
An object of \code{\link{class}} \code{"lmp"} is a list containing at least the following components:
 \item{coefficients}{A named vector of coefficients.}
 \item{residuals}{The residuals, that is response minus fitted values.}
 \item{fitted.values}{The fitted values.}
 \item{rank}{The numeric rank of the fitted linear model.}
 \item{df.residual}{The residual degrees of freedom computed as in \code{lm}.}
 \item{call}{The matched call.}
 \item{terms}{The \code{\link{terms}} object used.}
 \item{p}{Estimate of the structure parameter computed on residuals.}
 \item{knp}{A logical parameter used by \code{summary}.}
 \item{model}{The model frame used.}
 \item{iter}{If its value is 1 we have a difficult convergence.}
}
\references{Mineo, A.M. (1995) \emph{Stima dei parametri di regressione lineare semplice quando gli errori 
seguono una distribuzione normale di ordine p (p incognito)}. Annali della Facolt\`a di Economia dell'Universit\`a
di Palermo (Area Statistico-Matematica), pp. 161-186.
}
\examples{
e<-rnormp(n=100,mu=0,sigmap=4,p=3,method="d")
x<-runif(100)
y<-0.5+2*x+e
lmp(y~x)
}
\keyword{regression}
\author{Angelo M. Mineo}
\eof
\name{paramp}
\alias{paramp}
\alias{paramp.default}
\alias{print.paramp}
\title{Estimation of location and scale parameters}
\description{The function \code{paramp} returns a list with five elements: arithmetic mean, \eqn{M_p}{Mp},
standard deviation, \eqn{S_p}{Sp}, and structure parameter \eqn{p}{p}, estimated on a sample.
}
\usage{
paramp(x, p=NULL)
}
\arguments{
    \item{x}{A vector of observations.}
    \item{p}{If specified, the algorithm uses this value for \code{p},
                i.e. the algorithm does not use an estimate of \code{p}.}
    \item{...}{Further arguments passed to or from other methods.}
}
\value{The estimation of \eqn{\mu}{%
Mp} and \eqn{p}{p} is based on an iterative method. To show differences between the
least squares method and the maximum likelihood method, it prints out also the mean and the standard deviation.
\item{Mean}{Arithmetic mean.}
\item{Mp}{The estimated value of the location parameter.}
\item{Sd}{Standard deviation.}
\item{Sp}{The estimated value of the scale parameter.}
\item{p}{The estimated value of the structure parameter.}
\item{iter}{If its value is 1, we have had problems on convergence.}
}
\references{Mineo, A.M. (1996) \emph{La migliore combinazione delle osservazioni: curve normali di ordine p e
stimatori di norma Lp}. PhD thesis.
}
\examples{
x<-rnormp(1000,2,3,4.2)
paramp(x)
}
\keyword{univar}
\author{Angelo M. Mineo}
\eof
\name{plot.lmp}
\alias{plot.lmp}
\title{Diagnostic plots for an lmp object}
\description{This function produces four plots: a plot of residuals against fitted value, a Normal Q-Q plot,
a Normal of order \eqn{p}{p} Q-Q plot, a Scale-Location plot, with a \eqn{p}{p}-root of the standardized
residuals against the fitted values.
}
\usage{
\method{plot}{lmp}(x, ...)
}
\arguments{
    \item{x}{A \code{lmp} object, typically result of \code{\link{lmp}}.}
    \item{...}{Further arguments passed to or from other methods.}
}
\details{The standardized residuals in the Normal Q-Q plot are those of an object \code{\link{lm}};
in the Normal of order \eqn{p}{p} Q-Q plot and in the scale location plot the standardized residuals
are computed as \eqn{(e_i-m_p)/(s_p)}{(residuals-mp)/sp}.
}
\examples{
x<-1:20
z<-runif(20)
e<-rnormp(20,mu=0,sigmap=1,p=3)
y<-0.5+x+z+e
lmp.res<-lmp(y~x+z)
plot(lmp.res)
}
\keyword{hplot}
\author{Angelo M. Mineo}
\eof
\name{plot.simul.lmp}
\alias{plot.simul.lmp}
\title{Plots of the results of a simulation plan on a linear regression model}
\description{It returns the histograms of the estimates of the regression coefficients, of the scale
parameter \eqn{\sigma_p}{sigmap} and of the structure parameter \eqn{p}{p}.
}
\usage{
\method{plot}{simul.lmp}(x,...)
}
\arguments{
    \item{x}{A \code{simul.lmp} object, typically result of \code{\link{simul.lmp}}}
    \item{...}{Further arguments passed to or from other methods}
}
\value{The histograms of all the coefficients of the linear regression model and of the estimates of the scale
parameter \eqn{\sigma_p}{sigmap} and of the structure parameter \eqn{p}{p}.}
\examples{
sim<-simul.lmp(n=10,m=50,q=1,data=1.5,int=0,sigmap=1,p=3.5)
plot(sim)
}
\keyword{hplot}
\author{Angelo M. Mineo}
\eof
\name{plot.simul.mp}
\alias{plot.simul.mp}
\title{Plots of the results of a simulation plan on the parameters of a normal of order p distribution}
\description{It returns the histograms of the vector of means, estimates of \eqn{\mu}{Mp}, standard deviations,
estimates of \eqn{\sigma_p}{sigmap} and estimates of \eqn{p}{p}.
}
\usage{
\method{plot}{simul.mp}(x, ...)
}
\arguments{
    \item{x}{A \code{simul.mp} object, typically result of \code{\link{simul.mp}}}
    \item{...}{Further arguments passed to or from other methods}
}
\value{The histograms of the estimates of the parameters of a normal of order \eqn{p}{p} distribution.
}
\examples{
## The histograms of all the computed estimates
a<-simul.mp(100,50,mu=0,sigmap=1,p=3)
plot(a)
}
\keyword{hplot}
\author{Angelo M. Mineo}
\eof
\name{pnormp}
\alias{pnormp}
\title{Probability function of a Normal of Order p Distribution}
\description{Probability function for the normal of order \eqn{p}{p} distribution with location parameter
\code{mu}, scale parameter \code{sigmap} and structure parameter \code{p}.
}
\usage{
pnormp(q, mu=0, sigmap=1, p=2, lower.tail=TRUE, log.pr=FALSE)
}
\arguments{
    \item{q}{Vector of quantiles.}
    \item{mu}{Vector of location parameters.}
    \item{sigmap}{Vector of scale parameters.}
    \item{p}{Structure parameter.}
    \item{lower.tail}{Logical; if TRUE (default), probabilities are \eqn{P [X\leq x]}{%
    P[X <= x]}, otherwise, \eqn{P[X>x]}{P[X>x]}.}
    \item{log.pr}{Logical; if TRUE, probabilities \eqn{pr}{pr} are given as \eqn{log(pr)}{log(pr)}.}
}
\details{If \code{mu}, \code{sigmap} or \code{p} are not specified they assume the default values 0, 1 and 2,
respectively.
The normal of order \eqn{p}{p} distribution has density function

\deqn{f(x) = \frac{1}{2 p^{(1/p)} \Gamma(1+1/p) \sigma_p} e^{-\frac{|x - \mu|^p}{p \sigma_p^p}}}{%
f(x) = 1/(2 p^(1/p) Gamma(1+1/p) sigmap) exp{-|x - mu|^p/(p sigmap^p)}}

where \eqn{\mu}{mu} is the location parameter, \eqn{\sigma_p}{sigmap} the scale parameter and \eqn{p}{p} the
structure parameter.
When \eqn{p=2}{p=2} the Normal of Order \eqn{p}{p} Distribution becomes the Normal (Gaussian) Distribution,
when \eqn{p=1}{p=1} the Normal of Order \eqn{p}{p} Distribution becomes the Laplace Distribution, when
\eqn{p\rightarrow\infty}{p->infinity} the Normal of Order \eqn{p}{p} Distribution becomes the Uniform Distribution.
}
\value{\code{pnormp} gives the probability of a normal of order \eqn{p}{p} distribution.}
\seealso{\code{\link{Normal}} for the Normal distribution, \code{\link{Uniform}} for the Uniform distribution, and \code{\link{Special}} for the Gamma function. }
\examples{
## Compute the distribution function for a vector x with mu=0, sigmap=1 and p=1.5
## At the end we have the graph of the Normal of order 1.5 distribution function.
x <- c(-1, 1)
pr <- pnormp(x, p=1.5)
print(pr)
plot(function(x) pnormp(x, p=1.5), -4, 4,
          main = "Normal of order p Distribution Function (p=1.5)", ylab="F(x)")
}
\keyword{distribution}
\author{Angelo M. Mineo}
\eof
\name{qnormp}
\alias{qnormp}
\title{Quantiles of a Normal of Order p Distribution}
\description{Quantiles for the normal of order \eqn{p}{p} distribution with location parameter \code{mu},
scale parameter \code{sigmap} and structure parameter \code{p}.}
\usage{
qnormp(pr, mu=0, sigmap=1, p=2, lower.tail=TRUE, log.pr=FALSE)
}
\arguments{
    \item{pr}{Vector of probabilities.}
    \item{mu}{Vector of location parameters.}
    \item{sigmap}{Vector of scale parameters.}
    \item{p}{Structure parameter.}
    \item{lower.tail}{Logical; if TRUE (default), probabilities are \eqn{P [X\leq x]}{%
    P[X <= x]}, otherwise, \eqn{P[X>x]}{P[X>x]}.}
    \item{log.pr}{Logical; if TRUE, probabilities \eqn{pr}{pr} are given as \eqn{log(pr)}{log(pr)}.}
}
\details{If \code{mu}, \code{sigmap} or \code{p} are not specified they assume the default values 0, 1 and 2,
respectively.
The normal of order p distribution has density function

\deqn{f(x) = \frac{1}{2 p^{(1/p)} \Gamma(1+1/p) \sigma_p} e^{-\frac{|x - \mu|^p}{p \sigma_p^p}}}{%
f(x) = 1/(2 p^(1/p) Gamma(1+1/p) sigmap) exp{-|x - mu|^p/(p sigmap^p)}}

where \eqn{\mu}{mu} is the location parameter, \eqn{\sigma_p}{sigmap} the scale parameter and \eqn{p}{p} the
structure parameter.
When \eqn{p=2}{p=2} the Normal of Order \eqn{p}{p} Distribution becomes the Normal (Gaussian) Distribution, when
\eqn{p=1}{p=1} the Normal of Order \eqn{p}{p} Distribution becomes the Laplace Distribution, when
\eqn{p\rightarrow\infty}{p->infinity} the Normal of Order \eqn{p}{p} Distribution becomes the Uniform Distribution.
}
\value{\code{qnormp} gives the quantiles of a normal of order \eqn{p}{p} distribution.}
\seealso{\code{\link{Normal}} for the Normal distribution, \code{\link{Uniform}} for the Uniform distribution, and \code{\link{Special}} for the Gamma function. }
\examples{
## Compute the quantiles for a vector of probabilities x
## with mu=1, sigmap=2 and p=1.5
x <- 0.3
q <- qnormp(x, 1, 2, 1.5)
q
}
\keyword{distribution}
\author{Angelo Mineo}
\eof
\name{qqnormp}
\alias{qqnormp}
\alias{qqnormp.default}
\alias{qqlinep}
\title{Quantile-Quantile plot for a normal of order p distribution}
\description{The function \code{qqnormp} produces a normal of order \eqn{p}{p} Q-Q plot of the values in
\code{y}. The function \code{qqlinep} adds a line to a normal of order \eqn{p}{p} Q-Q plot going
through the first and the third quartile.
}
\usage{
qqnormp(y, ylim, p=2, main="Normal of order p Q-Q plot",
            xlab="Theoretical Quantiles", ylab="Sample Quantiles", ...)
qqlinep(y, p=2, ...)
}
\arguments{
    \item{y}{Vector of observations.}
    \item{p}{The structure parameter.}
    \item{main,xlab,ylab}{Plot labels.}
    \item{ylim, ...}{Graphical parameters}
}
\examples{
## Normal of order p Q-Q plot for a sample of 100 observations.
e<-rnormp(100,mu=0,sigmap=1,p=3)
qqnormp(e,p=3)
qqlinep(e,p=3)
}
\keyword{hplot}
\author{Angelo M. Mineo}
\eof
\name{rnormp}
\alias{rnormp}
\title{Pseudo-random numbers from a Normal of Order p Distribution}
\description{Generation of pseudo-random numbers from a normal of order \eqn{p}{p} distribution
with location parameter \code{mu}, scale parameter \code{sigmap} and structure parameter \code{p}.
}
\usage{rnormp(n, mu=0, sigmap=1, p=2, method="def")}
\arguments{
    \item{n}{Number of observations.}
    \item{mu}{Vector of location parameters.}
    \item{sigmap}{Vector of scale parameters.}
    \item{p}{Structure parameter.}
    \item{method}{If is set to the default method "\code{def}", it uses the method based on the
transformation of a Gamma random variable. If set to "\code{chiodi}", it uses an algorithm based on
a generalization of the Marsaglia formula to generate pseudo-random numbers from a gaussian distribution.
The default method "\code{def}" is faster than the "\code{chiodi}" one
(this one is introduced only for "historical" purposes).}
}
\details{If \code{mu}, \code{sigmap} or \code{p} are not specified they assume the default values 0, 1 and 2,
respectively.
The normal of order \eqn{p}{p} distribution has density function

\deqn{f(x) = \frac{1}{2 p^{(1/p)} \Gamma(1+1/p) \sigma_p} e^{- \frac{|x - \mu|^p}{p \sigma_p^p}}}{%
f(x) = 1/(2 p^(1/p) Gamma(1+1/p) sigmap) exp{-|x - mu|^p/(p sigmap^p)}}

where \eqn{\mu}{mu} is the location parameter, \eqn{\sigma_p}{sigmap} the scale parameter and \eqn{p}{p} the
structure parameter.
When \eqn{p=2}{p=2} the Normal of Order \eqn{p}{p} Distribution becomes the Normal (Gaussian) Distribution, when
\eqn{p=1}{p=1} the Normal of Order \eqn{p}{p} Distribution becomes the Laplace Distribution, when
\eqn{p\rightarrow\infty}{p->infinity} the Normal of Order \eqn{p}{p} Distribution becomes the Uniform Distribution.
}
\value{\code{rnormp} gives a vector of \eqn{n}{n} pseudo-random numbers from a normal of order \eqn{p}{p} distribution.}
\seealso{\code{\link{Normal}} for the Normal distribution, \code{\link{Uniform}} for the Uniform distribution,
\code{\link{Special}} for the Gamma function and \code{\link{.Random.seed}} for the random number generation.}
\references{
Chiodi, M. (1986) \emph{Procedures for generating pseudo-random numbers from a normal distribution of order p (p>1)},
Statistica Applicata, 1, pp. 7-26.

Marsaglia, G. and Bray, T.A. (1964) \emph{A convenient method for generating normal variables},
SIAM rev., 6, pp. 260-264.
}
\examples{
## Generate a random sample x from a normal of order p distribution
## At the end we have the histogram of x
x <- rnormp(1000, 1, 2, 1.5)
hist(x, main="Histogram of the random sample")
}
\keyword{distribution}
\author{Angelo M. Mineo}
\eof
\name{simul.lmp}
\alias{simul.lmp}
\title{Simulation planning for a linear regression model with errors distributed as a Normal of Order p}
\description{This function performs a Monte Carlo simulation to compare least squares estimators and
Maximum Likelihood estimators for a linear regression model with errors distributed as a normal of order
\eqn{p}{p} distribution. The regressors are drawn from a \link{Uniform} distribution.
}
\usage{
simul.lmp(n, m, q, data, int=0, sigmap=1, p=2, lp=FALSE)
}
\arguments{
    \item{n}{Sample size.}
    \item{m}{Number of samples.}
    \item{q}{Number of regressors.}
    \item{data}{A vector of coefficients.}
    \item{int}{Value of the intercept.}
    \item{sigmap}{The scale parameter.}
    \item{p}{The structure parameter.}
    \item{lp}{Logical. If \code{TRUE}, it evaluates the coefficients with p known.}
    }
\value{The function \code{simul.lmp} returns an object of class \code{"simul.lmp"}. A component of this object
is a table of means and variances of the \eqn{m}{m} estimates of the regression coefficients and
of the scale paramenter \eqn{\sigma_p}{sigmap}.
The \code{summary} shows this table and the arguments of the simulation plan. The function \code{plot}
returns the histograms of the computed estimates.
}
\references{Mineo, A.M. (1995) \emph{Stima dei parametri di regressione lineare semplice quando gli errori seguono una
distribuzione normale di ordine p (p incognito)}. Annali della Facolt\`a di Economia dell'Universit\`a
di Palermo (Area Statistico-Matematica), pp. 161-186.
}
\examples{
## Simulation of 50 samples of size 10 for a linear regression model with 1 regressor.
simul.lmp(10,50,1,data=1.5,int=1,sigmap=1,p=3,lp=FALSE)
}
\keyword{regression}
\author{Angelo M. Mineo}
\eof
\name{simul.mp}
\alias{simul.mp}
\alias{print.simul.mp}
\alias{simul.mp.default}
\title{Simulation planning for the parameters of a normal of order p distribution}
\description{This function performs a Monte Carlo simulation to compare least square estimators and
Maximum Likelihood estimators for the parameters of a normal of order \eqn{p}{p} distribution.
For each sample, it calls the function \code{\link{paramp}}, returning the arithmetic
means, the max-likelihood estimates of the location parameter, the standard deviations,
the max-likelihood estimates of the scale parameter and the estimates of the structure parameter.
}
\usage{
simul.mp(n, m, mu=0, sigmap=1, p=2)
}
\arguments{
    \item{n}{Sample size.}
    \item{m}{Number of samples.}
    \item{mu}{Value of the location parameter.}
    \item{sigmap}{Value of the scale parameter.}
    \item{p}{the structure parameter.}
}
\value{This function is useful to compare several kinds of estimators.
It returns an object of class \code{"simul.mp"}, a list containing the following components:
\item{dat}{A matrix \eqn{m\times 5}{m x 5} containing the results of \code{\link{paramp}} for each sample.}
\item{table}{A matrix reporting the means and the variances of the values of the five estimators.}
}
\references{Mineo, A.M. (1995) \emph{Stima dei parametri di intensit\`a e di scala di una curva normale
di ordine p (p incognito)}. Annali della Facolt\`a di Economia dell'Universit\`a di Palermo
(Area Statistico-Matematica), pp. 125-159.
}
\examples{
## Simulation plan for 100 samples of size 20, with mu=0, sigmap=1, p=3.
simul.mp(20,100,mu=0,sigmap=1,p=3)
}
\keyword{univar}
\author{Angelo M. Mineo}
\eof
\name{summary.lmp}
\alias{summary.lmp}
\alias{print.summary.lmp}
\title{Summarize linear model fits with normal of order p errors}
\description{This function is the \code{summary} method for class \code{"lmp"}. This function
produces a set of results for a linear regression model.
By assuming that in a linear regression model the errors
are distributed as a Normal of order \eqn{p}{p}, we can use the function \code{\link{lmp}}.}
}
\usage{
\method{summary}{lmp}(object, ...)
\method{print}{summary.lmp}(x, ...)
}
\arguments{
\item{object}{An object of class \code{"lmp"}, a result of a call to \code{\link{lmp}}.}
\item{x}{An object of class \code{"summary.lmp"}.}
\item{...}{Further arguments passed to or from other methods.}
}
\value{
The function \code{summary} returns a list of summary statistics of the fitted linear model 
given in \code{\link{lmp}}, using the components (list elements) \code{\link{call}} and \code{\link{terms}}
from its argument, plus

\item{Call}{The matched call.}
\item{Residuals}{A summary of the vector of residuals \eqn{e_i}{e[i]}.}
\item{Coefficients}{Vector of coefficients.}
\item{Estimate of p}{An estimate of the structure parameter \eqn{p}{p}.}
\item{Power deviation of order p}{The power deviation of order \eqn{p}{p} given by
\deqn{S_p = \left[\frac{\sum e_i^p}{n-q}\right]^\frac{1}{p}}{%
Sp = (1/(n-p) Sum(e[i]^p))^1/p}
where \eqn{q}{q} is or the number of the estimated regression coefficients if \eqn{p}{p} is known,
either the number of the estimated regression coefficients plus 1 if \eqn{p}{p} is estimated.}
}
\examples{
x<-runif(30)
e<-rnormp(30,0,3,1.25)
y<-0.5+x+e
L<-lmp(y~x)
summary(L)
}
\keyword{regression}
\author{Angelo M. Mineo}
\eof
\name{summary.simul.lmp}
\alias{summary.simul.lmp}
\alias{print.summary.simul.lmp}
\title{Summarize simulation results on linear regression model}
\description{This function is the \code{summary} method for class \code{"simul.lmp"}. This function
produces a set of results for a simulation plan for a linear regression model with
errors distributed as a normal of order \eqn{p}{p}.
}
\usage{
\method{summary}{simul.lmp}(object, ...)
\method{print}{summary.simul.lmp}(x, ...)
}
\arguments{
\item{object}{An object of class \code{"simul.lmp"}, a result of a call to \code{\link{simul.lmp}}.}
\item{x}{An object of class \code{"summary.simul.lmp"}, usually a result of a call to
              \code{\link{summary.simul.lmp}}.}
\item{...}{Further arguments passed to or from other methods.}
}
\value{
This function returns this information:
\item{Results}{Table containing the simulation results.}
\item{Coefficients}{The true values of coefficients used on the simulation model.}
\item{Formula}{The used linear regression model.}
\item{Number of samples}{Number of samples generated.}
\item{Value of p}{Value of the structure parameter \eqn{p}{p} used to draw the samples.}
\item{Number of samples with problems on convergence}{If \eqn{p}{p} is estimated, we have information on
      the number of samples with problems on convergence.}
}
\examples{
ris<-simul.lmp(100,20,2,data=c(3,2),int=0,sigmap=1,p=3)
summary(ris)
}
\keyword{regression}
\author{Angelo M. Mineo}
\eof
